package
Version:
v1.2.1
Opens a new window with list of versions in this module.
Published: May 26, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 14
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CreateForm struct {
Username string `form:"username" validate:"required,max=20"`
Password string `form:"password" validate:"required,min=4"`
ConfirmPassword string `form:"confirm_password" validate:"required"`
Role string `form:"role" validate:"required,role"`
}
type EditForm struct {
Password string `form:"password" validate:"omitempty,min=4"`
ConfirmPassword string `form:"confirm_password"`
Role string `form:"role" validate:"required,role"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.